==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/RedisquotaListFluent.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface RedisquotaListFluent<A extends RedisquotaListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,Redisquota item);
    public A setToItems(int index,Redisquota item);
    public A addToItems(Redisquota... items);
    public A addAllToItems(Collection<Redisquota> items);
    public A removeFromItems(Redisquota... items);
    public A removeAllFromItems(Collection<Redisquota> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Redisquota> getItems();
    public List<Redisquota> buildItems();
    public Redisquota buildItem(int index);
    public Redisquota buildFirstItem();
    public Redisquota buildLastItem();
    public Redisquota buildMatchingItem(Predicate<RedisquotaBuilder> predicate);
    public A withItems(List<Redisquota> items);
    public A withItems(Redisquota... items);
    public Boolean hasItems();
    public RedisquotaListFluent.ItemsNested<A> addNewItem();
    public RedisquotaListFluent.ItemsNested<A> addNewItemLike(Redisquota item);
    public RedisquotaListFluent.ItemsNested<A> setNewItemLike(int index,Redisquota item);
    public RedisquotaListFluent.ItemsNested<A> editItem(int index);
    public RedisquotaListFluent.ItemsNested<A> editFirstItem();
    public RedisquotaListFluent.ItemsNested<A> editLastItem();
    public RedisquotaListFluent.ItemsNested<A> editMatchingItem(Predicate<RedisquotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,RedisquotaFluent<RedisquotaListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/redisquota/RedisquotaListFluent.java <==
package me.snowdrop.istio.mixer.adapter.redisquota;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface RedisquotaListFluent<A extends RedisquotaListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Redisquota item);
    public A setToItems(int index,Redisquota item);
    public A addToItems(Redisquota... items);
    public A addAllToItems(Collection<Redisquota> items);
    public A removeFromItems(Redisquota... items);
    public A removeAllFromItems(Collection<Redisquota> items);
    public A removeMatchingFromItems(Predicate<RedisquotaBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Redisquota> getItems();
    public List<Redisquota> buildItems();
    public Redisquota buildItem(int index);
    public Redisquota buildFirstItem();
    public Redisquota buildLastItem();
    public Redisquota buildMatchingItem(Predicate<RedisquotaBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<RedisquotaBuilder> predicate);
    public A withItems(List<Redisquota> items);
    public A withItems(Redisquota... items);
    public Boolean hasItems();
    public RedisquotaListFluent.ItemsNested<A> addNewItem();
    public RedisquotaListFluent.ItemsNested<A> addNewItemLike(Redisquota item);
    public RedisquotaListFluent.ItemsNested<A> setNewItemLike(int index,Redisquota item);
    public RedisquotaListFluent.ItemsNested<A> editItem(int index);
    public RedisquotaListFluent.ItemsNested<A> editFirstItem();
    public RedisquotaListFluent.ItemsNested<A> editLastItem();
    public RedisquotaListFluent.ItemsNested<A> editMatchingItem(Predicate<RedisquotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,RedisquotaFluent<RedisquotaListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
